# mypy-boto3-schemas<a id="mypy-boto3-schemas"></a>

[![PyPI - mypy-boto3-schemas](https://img.shields.io/pypi/v/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-schemas?color=blue)](https://pypistats.org/packages/mypy-boto3-schemas)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Schemas 1.17.69](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/schemas.html#Schemas)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-buider 4.12.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-schemas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_schemas/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-schemas](#mypy-boto3-schemas)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

## How to install<a id="how-to-install"></a>

Install `boto3-stubs` for `Schemas` service.

```bash
python -m pip install boto3-stubs[schemas]
```

## Usage<a id="usage"></a>

### VSCode<a id="vscode"></a>

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service. No
explicit type annotations required, write your `boto3` code as usual.

### PyCharm<a id="pycharm"></a>

- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`

Both type checking and auto-complete should work for `Schemas` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

### Other IDEs<a id="other-ides"></a>

Not tested, but as long as your IDE support `mypy` or `pyright`, everything
should work.

### mypy<a id="mypy"></a>

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`
- Run `mypy` as usual

Type checking should work for `Schemas` service. No explicit type annotations
required, write your `boto3` code as usual.

### pyright<a id="pyright"></a>

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[schemas]` in your environment:
  `python -m pip install 'boto3-stubs[schemas]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Schemas` service. No explicit type annotations
required, write your `boto3` code as usual.

## Explicit type annotations<a id="explicit-type-annotations"></a>

### Client annotations<a id="client-annotations"></a>

`SchemasClient` provides annotations for `boto3.client("schemas")`.

```python
import boto3

from mypy_boto3_schemas import SchemasClient

client: SchemasClient = boto3.client("schemas")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SchemasClient = session.client("schemas")
```

### Paginators annotations<a id="paginators-annotations"></a>

`mypy_boto3_schemas.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.paginator import (
    ListDiscoverersPaginator,
    ListRegistriesPaginator,
    ListSchemaVersionsPaginator,
    ListSchemasPaginator,
    SearchSchemasPaginator,
)

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_discoverers_paginator: ListDiscoverersPaginator = client.get_paginator("list_discoverers")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
search_schemas_paginator: SearchSchemasPaginator = client.get_paginator("search_schemas")
```

### Waiters annotations<a id="waiters-annotations"></a>

`mypy_boto3_schemas.waiter` module contains type annotations for all waiters.

```python
from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.waiter import (
    CodeBindingExistsWaiter,
)

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
code_binding_exists_waiter: CodeBindingExistsWaiter = client.get_waiter("code_binding_exists")
```

### Literals<a id="literals"></a>

`mypy_boto3_schemas.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_schemas.literals import (
    CodeBindingExistsWaiterName,
    CodeGenerationStatus,
    DiscovererState,
    ListDiscoverersPaginatorName,
    ListRegistriesPaginatorName,
    ListSchemaVersionsPaginatorName,
    ListSchemasPaginatorName,
    SearchSchemasPaginatorName,
    TypeType,
)

def check_value(value: CodeBindingExistsWaiterName) -> bool:
    ...
```

### Typed dictionaries<a id="typed-dictionaries"></a>

`mypy_boto3_schemas.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_schemas.type_defs import (
    CreateDiscovererResponseTypeDef,
    CreateRegistryResponseTypeDef,
    CreateSchemaResponseTypeDef,
    DescribeCodeBindingResponseTypeDef,
    DescribeDiscovererResponseTypeDef,
    DescribeRegistryResponseTypeDef,
    DescribeSchemaResponseTypeDef,
    DiscovererSummaryTypeDef,
    ExportSchemaResponseTypeDef,
    GetCodeBindingSourceResponseTypeDef,
    GetDiscoveredSchemaResponseTypeDef,
    GetResourcePolicyResponseTypeDef,
    ListDiscoverersResponseTypeDef,
    ListRegistriesResponseTypeDef,
    ListSchemaVersionsResponseTypeDef,
    ListSchemasResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    PaginatorConfigTypeDef,
    PutCodeBindingResponseTypeDef,
    PutResourcePolicyResponseTypeDef,
    RegistrySummaryTypeDef,
    SchemaSummaryTypeDef,
    SchemaVersionSummaryTypeDef,
    SearchSchemaSummaryTypeDef,
    SearchSchemaVersionSummaryTypeDef,
    SearchSchemasResponseTypeDef,
    StartDiscovererResponseTypeDef,
    StopDiscovererResponseTypeDef,
    UpdateDiscovererResponseTypeDef,
    UpdateRegistryResponseTypeDef,
    UpdateSchemaResponseTypeDef,
    WaiterConfigTypeDef,
)

def get_structure() -> CreateDiscovererResponseTypeDef:
    return {
      ...
    }
```

## Versioning<a id="versioning"></a>

`mypy-boto3-schemas` version is the same as related `boto3` version and follows
[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Documentation<a id="documentation"></a>

All type annotations can be found in
[mypy-boto3-schemas docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_schemas/)

## Support and contributing<a id="support-and-contributing"></a>

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
